Module: IntercomRails::CustomDataHelper

Defined in:
lib/intercom-rails/custom_data_helper.rb

Defined Under Namespace

Classes: STORE

Instance Method Summary collapse

Instance Method Details

#intercom_custom_dataObject

This helper allows custom data attributes to be added to a user for the current request from within the controller. e.g.

def destroy

intercom_custom_data.user['canceled_at'] = Time.now
...

end



13
14
15
# File 'lib/intercom-rails/custom_data_helper.rb', line 13

def intercom_custom_data
  @_request_specific_intercom_custom_data ||= STORE.new({}, {})
end